@@ -30,29 +30,6 @@
 #include "window.h"
 #include "workspace.h"
 
-typedef enum _MetaCompWindowType
-{
-  META_COMP_WINDOW_NORMAL = META_WINDOW_NORMAL,
-  META_COMP_WINDOW_DESKTOP =  META_WINDOW_DESKTOP,
-  META_COMP_WINDOW_DOCK = META_WINDOW_DOCK,
-  META_COMP_WINDOW_DIALOG = META_WINDOW_DIALOG,
-  META_COMP_WINDOW_MODAL_DIALOG = META_WINDOW_MODAL_DIALOG,
-  META_COMP_WINDOW_TOOLBAR = META_WINDOW_TOOLBAR,
-  META_COMP_WINDOW_MENU = META_WINDOW_MENU,
-  META_COMP_WINDOW_UTILITY = META_WINDOW_UTILITY,
-  META_COMP_WINDOW_SPLASHSCREEN = META_WINDOW_SPLASHSCREEN,
-
-  /* override redirect window types, */
-  META_COMP_WINDOW_DROPDOWN_MENU = META_WINDOW_DROPDOWN_MENU,
-  META_COMP_WINDOW_POPUP_MENU = META_WINDOW_POPUP_MENU,
-  META_COMP_WINDOW_TOOLTIP = META_WINDOW_TOOLTIP,
-  META_COMP_WINDOW_NOTIFICATION = META_WINDOW_NOTIFICATION,
-  META_COMP_WINDOW_COMBO = META_WINDOW_COMBO,
-  META_COMP_WINDOW_DND = META_WINDOW_DND,
-  META_COMP_WINDOW_OVERRIDE_OTHER = META_WINDOW_OVERRIDE_OTHER
-
-} MetaCompWindowType;
-
 /**
  * MetaCompEffect:
  * @META_COMP_EFFECT_CREATE: The window is newly created
